<?php

/**
 * portaLE.class.php
 * 
 * This file contains the main class of the plugin
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 * 
 * @author Heiko Dostert <dosterth@uni-trier.de>
 * @package portaLE
 * @copyright Universitt Trier, Koordinationsstelle E-Learning, 2010
 * @version 1.0.0
 * @version 1.0.2 - 22.11.2010 - Jrg Rpke <roepke@uni-trier.de>
 * @version 1.0.5 - 20.12.2011 - Paul C. Sommerhoff <somm4702@uni-trier.de>
 */

require_once dirname(__FILE__) . '/config/config_portale.inc.php';
require_once dirname(__FILE__) . '/classes/OmGateway.class.php';
require_once dirname(__FILE__) . '/classes/Timetable.class.php';
require_once dirname(__FILE__) . '/classes/Waitingroom.class.php';
require_once dirname(__FILE__) . '/classes/PortaleException.class.php';


class portaLE extends AbstractStudIPStandardPlugin
{
    var $template_factory;
    var $user;
    var $permission;
    var $year;
    var $numOfNewRooms;
    
	public function __construct()
	{
		// set navigation
		parent::AbstractStudIPStandardPlugin();
		$this->setPluginiconname('../../../assets/images/icons/16/grey/video.png');
		$this->setChangeindicatoriconname('../../../assets/images/icons/16/red/video.png');
        $this->setShownInOverview(true);
		$this->user = $this->getUser();
		$this->permission = $this->user->getPermission();
		$this->template_factory = new Flexi_TemplateFactory(dirname(__FILE__).'/templates/');
		$today = getdate();
		if(is_array($today))
			$this->year = $today['year'];

		$nav = new PluginNavigation();
		$nav->setDisplayname(_("Virtuelle Rume"));
		$nav->addLinkParam('action', 'main');
		  
		if($this->permission->hasTutorPermissionInPOI()){
			$config_nav =& new PluginNavigation();
			$config_nav->setDisplayname(_("Neuen Raum anlegen "));
			$config_nav->addLinkParam('action', 'config');
			$nav->addSubmenu($config_nav);
		}
		if($_REQUEST['action'] == 'waitingroom'){
			$config_nav =& new PluginNavigation();
			$config_nav->setDisplayname(_("Wartezimmer"));
			$config_nav->addLinkParam('action', 'waitingroom');
			$config_nav->addLinkParam('id', $_REQUEST['id']);
/*			$config_nav->addLinkParam('server', $_REQUEST['server']);
			$config_nav->addLinkParam('room_id', $_REQUEST['room_id']); */
			$nav->addSubmenu($config_nav);
		}
		$this->setNavigation($nav);
	}


	function getPluginname()
	{
		return _('portaLE');
	}


    function initialize ()
    {
        global $HELP_KEYWORD;

        if (!isset($HELP_KEYWORD))
            $HELP_KEYWORD = 'Basis.portaLE';
    }
	
	public function actionshow()
	{
		$action = $_REQUEST['action'];
		if(isset($_REQUEST['delete_room_x']) && $this->permission->hasTutorPermissionInPOI()){  //deletion of a classroom selected => ask for confirmation
			$msg = _("Soll der Raum \"".$_REQUEST['room_title']."\" (".$_REQUEST['room_date'].") wirklich gelscht werden?");
			$msg .= "<p align=\"center\"><b><a href=\"".PluginEngine::getLink($this, array('action' => 'main', 'view' => $view, 'confirm_delete' => true, 'del_id' => $_REQUEST['id']))."\">" . makeButton("ja2", "img") . "</a>&nbsp;&nbsp; <a href=\"".PluginEngine::getLink($this, array('action' => 'main', 'view' => $view))."\">" . makeButton("nein", "img") . "</a></b></p>";
			echo MessageBox::info($msg);
			echo "<br/>";
			$action = 'main';            
		}
		if($action == 'config')
			$this->displayConfigPage();
		elseif($action == 'waitingroom')
			$this->displayWaitingroom();
		else
			$this->displayMainPage();			 		
   }  //End actionshow


	function hasChanged ($lastlogin)
	{
		$this->numOfNewRooms = Timetable::GetNumberOfNewRooms($this->getId(), $lastlogin);
		if($this->numOfNewRooms === false)
			return false;
		return ($this->numOfNewRooms > 0);
	}

	
	function getOverviewMessage ($has_changed=false)
	{
		if ($has_changed){
			if($this->numOfNewRooms == 1)
				return _("1 neuer virtueller Raum");
			else	
				return sprintf(_("%d neue virtuelle Rume"), $this->numOfNewRooms);
		}
		return _("Virtuelle Rume");
	}
	
	
	private function displayMainPage()
	{
		global $INDIRECT_ENTRY_ROOM, $ANARCHY_ROOM, $OM_SERVERS;
		
		if(isset($_REQUEST['view']))
				$view = $_REQUEST['view'];
			else
				$view = 'standard';
		if(isset($_REQUEST['confirm_delete']) && ($_REQUEST['confirm_delete'] == true) && $this->permission->hasTutorPermissionInPOI()){  //user has confirmed deletion
			if(Timetable::deleteRoom(Request::int('del_id')))
				echo MessageBox::success(_("Der Raum wurde gelscht"));
			else
				echo MessageBox::error(_("Der Raum kann nicht gelscht werden"));
			echo "<br/>";
		}
		if(isset($_REQUEST['enter_room_x'])){  //open a classroom in an new window
			try{
				$classroom = Timetable::getRoomById(Request::int('id'));
				if($classroom !== false){
					$mod = ($this->permission->hasTutorPermissionInPOI() || (in_array($classroom->roomtype, $ANARCHY_ROOM)));
					$ticket = Classroom::enter($this->user, $mod, Request::int('id'));
					echo "<script type=\"text/javascript\">win = window.open('".$this->getPluginURL()."/html/maximize_window.html?url=$ticket', '', ''); win.focus();</script>";
					echo MessageBox::info(_("Falls der virtuelle Raum nicht automatisch ffnet, klicken Sie bitte")." <a href=\"".$this->getPluginURL()."/html/maximize_window.html?url=$ticket\">"._("hier")."</a>.");
					echo "<br/>";
				}
				else
					echo MessageBox::error(_("Der Raum kann nicht gefunden werden."));
					
				// statistics
				$q = "UPDATE portaLE_statistics SET jumps=jumps+1 WHERE week < ".time()." ORDER BY week DESC LIMIT 1;";
				DBManager::Get()->exec($q);	
			}
			catch(PortaleException $exception){
				echo MessageBox::error($exception->getMessage());
				echo "<br/>";
			}
		}
		try{
			Timetable::cleanPortaLE();
			$classrooms = Timetable::getRooms($this->permission->hasTutorPermissionInPOI());
		}
		catch (Exception $e){
			$classrooms = false;
			if(defined('MAIL_ADMIN'))
				mail(MAIL_ADMIN, _('Fehler bei Openmeetings-Zugriff'), sprintf(_('Beim Zugriff auf das SharingInterface ist in der Funktion displayRooms() (Zeile %d, Datei %s) der folgende Fehler aufgetreten: %s'), __LINE__, __FILE__, $e));
		}
		$template = $this->template_factory->open('main');
		$template->set_attribute('view', $view);
		$template->set_attribute('classrooms', $classrooms);
		$template->set_attribute('permission', $this->permission);
		$template->set_attribute('direct_link', PluginEngine::getLink($this, array('action' => 'main')));
		$template->set_attribute('waiting_link', PluginEngine::getLink($this, array('action' => 'waitingroom')));
		$template->set_attribute('INDIRECT_ENTRY_ROOMS', $INDIRECT_ENTRY_ROOM);
		$template->set_attribute('servers', $OM_SERVERS);
		$template->set_attribute('infobox', $this->getInfoBox('main', $this->permission->hasTutorPermissionInPOI(), $view));
		echo $template->render();
	}  //End displayMainPage

	
	private function displayConfigPage()
	{
		global $ROOMTYPES, $LENGTH_SELECTION, $NUMBERS_OF_PARTICIPANTS, $BENEFICIARY_DOZENTIN, $TO_TEST, $OM_SERVERS;
		
		if($_REQUEST['addclassroom'] == 'true'){  //add a new classroom
			$title = Request::quoted('title');
			$roomtype = Request::option('roomtype');
			$teacher = Request::option('teacher');
			$hour = Request::int('hour');
			$minute = Request::int('minute');
			$month = Request::int('month');
			$day = Request::int('day');
			$year = Request::int('year');
			$length = (Request::int('length')*60);
			$numberOfParticipants = Request::int('numberOfParticipants');
			$group_id = Request::option('group');
			if($_REQUEST['nextday'] == 'true') {
				$timestamp = mktime($hour, $minute, 0, $month, $day, $year) + 3600 * 24;
				$day = date("j", $timestamp);
				$month = date("n", $timestamp);
				$year = date("Y", $timestamp);
			} else if($_REQUEST['daybefore'] == 'true') {
				$timestamp = mktime($hour, $minute, 0, $month, $day, $year) - 3600 * 24;
				$day = date("j", $timestamp);
				$month = date("n", $timestamp);
				$year = date("Y", $timestamp);
			}
				if($TO_TEST === TRUE && !$this->permission->hasRootPermission() && array_search($this->user->userid, $BENEFICIARY_DOZENTIN) === FALSE)
						echo MessageBox::error(_('Diese Funktion befindet sich noch in der Testphase. Es wurde kein virtueller Raum angelegt. Bitte wenden Sie sich an den Systemadministrator.'));
				else{
					try{
						if($_REQUEST['nextday'] == 'true' || $_REQUEST['daybefore'] == 'true')
							throw new PortaleException();
						Timetable::addRoom($title, $roomtype, $teacher, $hour, $minute, $month, $day, $year, $length, $numberOfParticipants, $group_id);
						echo MessageBox::success(_('Der virtuelle Klassenraum wurde angelegt.'));
					}
					catch(PortaleException $exception){
						if (!($_REQUEST['nextday'] == 'true' || $_REQUEST['daybefore'] == 'true'))
							echo MessageBox::error(_('Der Raum konnte nicht angelegt werden:<div class="messagebox_details"><ul><li>'.$exception->getMessage().'</li></ul></div>'));
						
						// Raumbelegung
							
						$timeline=
"<style type='text/css'> 
.occupied {
background-color: red;
height: 1px;
}
 
.free {
background-color: green;
height: 1px;
}
 
.partly_occupied {
background-color: blue;
height: 1px;
}

.helpline{
border-left:1px dotted #000; 
}
</style>
<table width='90%' border='0' style='padding: 20px'><tr><td align='left'>Raumbelegung:</td></tr>
<tr><td align='center' width='10%'>
<a href='?action=config&addclassroom=true&daybefore=true&title=$title&roomtype=$roomtype&teacher=$teacher&hour=$hour&minute=$minute&month=$month&day=$day&year=$year&length=$length&numberOfParticipants=$numberOfParticipants&group=$group_id'>".Assets::img('icons/16/blue/arr_1left.png', array('title' => _('zu vorherigem Tag')))."</a>
</td><td align='center'>
<table height='80' width='100%' border='0'>
<tr  height='5%' align='left' >
    <td width='8%' colspan='4' class='helpline'><font size='-2'>$day.$month.$year</font></td>
	<td width='8%' colspan='4'></td>
    <td width='8%' colspan='4'></td>
	<td width='8%' colspan='4'></td>
    <td width='8%' colspan='4'></td>
    <td width='8%' colspan='4'></td>
    <td width='8%' colspan='4'></td>
    <td width='8%' colspan='4'></td>
    <td width='8%' colspan='4'></td>
    <td width='8%' colspan='4'></td>
    <td width='8%' colspan='4'></td>
    <td width='8%' colspan='4'></td>
  </tr>
  <tr align='left' >
    <td width='8%' colspan='4' class='helpline'><font size='-2'>0:00</font></td>
	<td width='8%' colspan='4' class='helpline'><font size='-2'>2:00</font></td>
    <td width='8%' colspan='4' class='helpline'><font size='-2'>4:00</font></td>
	<td width='8%' colspan='4' class='helpline'><font size='-2'>6:00</font></td>
    <td width='8%' colspan='4' class='helpline'><font size='-2'>8:00</font></td>
    <td width='8%' colspan='4' class='helpline'><font size='-2'>10:00</font></td>
    <td width='8%' colspan='4' class='helpline'><font size='-2'>12:00</font></td>
    <td width='8%' colspan='4' class='helpline'><font size='-2'>14:00</font></td>
    <td width='8%' colspan='4' class='helpline'><font size='-2'>16:00</font></td>
    <td width='8%' colspan='4' class='helpline'><font size='-2'>18:00</font></td>
    <td width='8%' colspan='4' class='helpline'><font size='-2'>20:00</font></td>
    <td width='8%' colspan='4' class='helpline'><font size='-2'>22:00</font></td>
  </tr><!--
   <tr  height='5%' align='left' >
    <td width='8%' class='helpline'></td>
	<td width='8%' class='helpline'></td>
    <td width='8%' class='helpline'></td>
	<td width='8%' class='helpline'></td>
    <td width='8%' class='helpline'></td>
    <td width='8%' class='helpline'></td>
    <td width='8%' class='helpline'></td>
    <td width='8%' class='helpline'></td>
    <td width='8%' class='helpline'></td>
    <td width='8%' class='helpline'></td>
    <td width='8%' class='helpline'></td>
    <td width='8%' class='helpline'></td>
  </tr>-->
   <tr height='4' align='left'>";
						$maxCapacity = 0;
						$mysqlstartdate = date( 'Y-m-d H:i:s', mktime(0, 0, 0, $month, $day, 1999));
						$mysqlenddate = date( 'Y-m-d H:i:s', (mktime(0, 0, 0, $month, $day, 1999)));
						foreach($OM_SERVERS AS $key => $value){
							$options = array("location" => $value['SHARINGINTERFACE_LOCATION'],       
							"uri" => $value['SHARINGINTERFACE_URI'],                  
							"style" => $value['SHARINGINTERFACE_STYLE'],                                
							"use" => $value['SHARINGINTERFACE_USE']);
							try{
								$interface = new SoapClient(null, $options);
								$capacity = $interface->getCapacity($mysqlstartdate, $mysqlenddate, $value['SEC_KEY']);
							} catch(Exception $e){}
							if($capacity > $maxCapacity){
								$maxCapacity = $capacity;
							}
						}
						
						if(array_search($numberOfParticipants, $NUMBERS_OF_PARTICIPANTS) > 0) {
							$n = array_search($numberOfParticipants, $NUMBERS_OF_PARTICIPANTS);
							$newNoP = $NUMBERS_OF_PARTICIPANTS[$n-1];
						} else 
							$newNoP = $NUMBERS_OF_PARTICIPANTS[0];
						
						for($i=0; $i<12; $i++) {
							for($j=0; $j<4; $j++) {
								$freeCapacity = 0;
								$mysqlstartdate = date( 'Y-m-d H:i:s', mktime(floor($i*2+$j/2), ($j*30)%60, 0, $month, $day, $year));
								$mysqlenddate = date( 'Y-m-d H:i:s', (mktime(floor($i*2+$j/2), ($j*30)%60, 0, $month, $day, $year)+30*60));
								foreach($OM_SERVERS AS $key => $value){
									$options = array("location" => $value['SHARINGINTERFACE_LOCATION'],       
									"uri" => $value['SHARINGINTERFACE_URI'],                  
									"style" => $value['SHARINGINTERFACE_STYLE'],                                
									"use" => $value['SHARINGINTERFACE_USE']);
									try{
										$interface = new SoapClient(null, $options);
										$capacity = $interface->getCapacity($mysqlstartdate, $mysqlenddate, $value['SEC_KEY']);
									}
									catch(Exception $e){
									}
									if($capacity > $freeCapacity){
										$freeCapacity = $capacity;
									}
								}
								
								if ($freeCapacity >= $numberOfParticipants) {
									$timeline .= "<td class='free'></td>";
								} else if($freeCapacity >= $newNoP)
									$timeline .= "<td class='partly_occupied'></td>";
		    					else
		    						$timeline .= "<td class='occupied'></td>"; 
							}
						}
					$text = "Legende\n\nGrne Balken symbolisieren, dass hier ausreichende Ressourcen fr den gewnschten virtuellen Raum verfgbar sind.\nSteht die nchst kleinere Anzahl an Pltzen zur Verfgung, werden die Teilbalken blau dargestellt.\nRote Balken signalisieren, dass fr die gewnschte Raumgre keine annhernden Kapazitten bereit stehen.";
    				$timeline .= "
    </tr>
  <tr height='25' align='left'>
  	<td></td>
	<td colspan='42'><font size='-2' color='green'>frei&nbsp;&nbsp;&nbsp;</font>
	<font size='-2' color='red'>belegt&nbsp;&nbsp;&nbsp;</font>
    <font size='-2' color='blue'>reduziert mit $newNoP Personen m&ouml;glich</font>
    ".Assets::img('icons/16/grey/info-circle.png', tooltip(_($text), TRUE, TRUE))."</td>
  </tr>
</table></td><td align='center' width='10%'>
<a href='?action=config&addclassroom=true&nextday=true&title=$title&roomtype=$roomtype&teacher=$teacher&hour=$hour&minute=$minute&month=$month&day=$day&year=$year&length=$length&numberOfParticipants=$numberOfParticipants&group=$group_id'>".Assets::img('icons/16/blue/arr_1right.png', array('title' => _('zu n&auml;chstem Tag')))."</a>
</td></tr>
</table>";
					echo $timeline;
			
					// Ende Raumbelegung 
			
  					}
			}
			// statistics
			$db = DBManager::Get();
			$q = "SELECT week FROM portaLE_statistics WHERE week < ".mktime($hour, $minute, 0, $month, $day, $year)." ORDER BY week DESC LIMIT 1;";
			$data = $db->query($q)->fetch();
			$new_week = $data['week'];			 
			while(($new_week + (7*24*60*60)) < mktime($hour, $minute, 0, $month, $day, $year)) {
				$new_week += 7*24*60*60;
			}
			if ($new_week != $data['week']) {
				$db->exec("INSERT IGNORE INTO portaLE_statistics SET week = $new_week, room_count=0, people_count=0, jumps=0");
			}			
			$q = "UPDATE portaLE_statistics SET room_count=room_count+1, people_count=people_count+$numberOfParticipants WHERE week < ".mktime($hour, $minute, 0, $month, $day, $year)." ORDER BY week DESC LIMIT 1;";
			DBManager::Get()->exec($q);
  		}
  		$template = $this->template_factory->open('admin');
  		$template->set_attribute('msg', $msg);
  		$template->set_attribute('plugin', $this);
  		$template->set_attribute('config', $this->config);
  		$template->set_attribute('year', $this->year);
  		$template->set_attribute('ROOMTYPES', $ROOMTYPES);
  		$template->set_attribute('LENGTH_SELECTION', $LENGTH_SELECTION);
  		$template->set_attribute('NUMBERS_OF_PARTICIPANTS', $NUMBERS_OF_PARTICIPANTS);
  		$template->set_attribute('infobox', $this->getInfoBox('config', $this->permission->hasTutorPermissionInPOI()));
  		echo $template->render();
  }  //End displayConfigPage

  	
	private function displayWaitingroom(){
		global $ANARCHY_ROOM;
		$classroom = Timetable::getRoomById(Request::int('id'));
		if($classroom===false){  //if there is no corresponding conference room with this id break
			echo MessageBox::error(_('Das Wartezimmer kann nicht geffnet werden. Bitte wenden Sie sich an den Administrator'));
			return;
		}
		if((strtotime($classroom->date) + $classroom->length + TIME_OFFSET) < time()){
			echo MessageBox::error(_('Die Veranstaltung ist beendet.'));
			return;
		}
		if($this->permission->hasTutorPermissionInPOI()){
			if(isset($_REQUEST['closeroom'])){
				if($_REQUEST['closeroom']=='true'){
					Waitingroom::close(Request::int('id'));
					echo MessageBox::info(_('Der Warteraum ist nun geschlossen.'));
				}
				else{
					Waitingroom::close(Request::int('id'), false);
					echo MessageBox::info(_('Der Warteraum ist wieder geffnet.'));
				}
			}
/*			if(isset($_REQUEST['kick'])){
				Classroom::kickAll(Request::int('id'));
				echo MessageBox::info(_('Der virtuelle Raum wurde geleert.'));
			} */
			if(isset($_REQUEST['send_message_x'])){
				$message = strip_tags(Request::quoted('message'));
				Waitingroom::sendMessage(Request::int('id'), $message);
			}
		}
		if(isset($_REQUEST['enter_waitingroom_x'])){
			if($this->permission->hasTutorPermissionInPOI()){  //direct entry to virtual room
				try{
					$ticket = Classroom::enter($this->user, true, Request::int('id'));
					if($ticket !== false){
						echo "<script type=\"text/javascript\">win = window.open('".$this->getPluginURL()."/html/maximize_window.html?url=$ticket', '', ''); win.focus();</script>";
						echo MessageBox::info(_("Falls der virtuelle Raum nicht automatisch ffnet, klicken Sie bitte")." <a href=\"".$this->getPluginURL()."/html/maximize_window.html?url=$ticket\">"._("hier")."</a>.");
					}
					else
						echo MessageBox::error(_('Der Raum kann nicht geffnet werden.'));
					
					// statistics
					$q = "UPDATE portaLE_statistics SET jumps=jumps+1 WHERE week < ".time()." ORDER BY week DESC LIMIT 1;";
					DBManager::Get()->exec($q);	
				}
				catch(PortaleException $e){
					echo MessageBox::error($exception->getMessage());
				}
			}
			else{  //sit down in the waiting room
				Waitingroom::enterRoom(Request::int('id'), $this->user);
				echo MessageBox::info(_("Sie haben nun das Wartezimmer betreten"));
			}
		}
		if(isset($_REQUEST['allow_entry_x']) && $this->permission->hasTutorPermissionInPOI()){
			Waitingroom::allowEntry(Request::int('id'), $_REQUEST['user_id']);
		}
		if(isset($_REQUEST['delete_person_x']) && (($_REQUEST['user_id'] == $this->user->getUserid()) || $this->permission->hasTutorPermissionInPOI())){
			Waitingroom::leaveRoom(Request::int('id'), $_REQUEST['user_id']);
		}
		if(!$this->permission->hasTutorPermissionInPOI()){
			if(Waitingroom::hasEntryPermission(Request::int('id'), $this->user->getUserid())){
				try{
					$ticket = Classroom::enter($this->user, in_array($classroom->roomtype, $ANARCHY_ROOM), Request::int('id'));
					Waitingroom::leaveRoom(Request::int('id'), $this->user->getUserid());
					echo "<script type=\"text/javascript\">win = window.open('".$this->getPluginURL()."/html/maximize_window.html?url=$ticket', '', ''); win.focus();</script>";
					echo MessageBox::success(_("Sie knnen den virtuellen Raum nun betreten. Falls dieser nicht automatisch ffnet, klicken Sie bitte")." <a href=\"".$this->getPluginURL()."/html/maximize_window.html?url=$ticket\" >"._("hier")."</a>.");
					// statistics
					$q = "UPDATE portaLE_statistics SET jumps=jumps+1 WHERE week < ".time()." ORDER BY week DESC LIMIT 1;";
					DBManager::Get()->exec($q);	
				}
				catch(PortaleException $exception){
					echo MessageBox::error($exception->getMessage());
					echo "<br/>";
					$entrypermission = true;
				}
			}							
		}
		$waitingList = Waitingroom::getWaitinglist(Request::int('id'));
		if($entrypermission === true)  //if entry failed although permit was granted try again the next period
			$time = 0;
		else
			$time = Waitingroom::getTimeOfWaitinglist(Request::int('id'));
		$template = $this->template_factory->open('waitingroom');
		$template->set_attribute('classroom', Waitingroom::getClassroomInfo(Request::int('id')));
		$template->set_attribute('link', PluginEngine::getLink($this, array('action' => 'waitingroom')));
		$template->set_attribute('reloadLink', PluginEngine::getLink($this));
		$template->set_attribute('pluginPath', $this->getPluginURL());
		$template->set_attribute('hasTeacherPermission', $this->permission->hasTutorPermissionInPOI());
		$template->set_attribute('userId', $this->user->getUserId());
		$template->set_attribute('time', $time);
		$template->set_attribute('waitingList', $waitingList);
		if(isset($ticket))
			$template->set_attribute('ticket', $ticket);
		$template->set_attribute('infobox', $this->getInfoBox('waitingroom', $this->permission->hasTutorPermissionInPOI()));
		echo $template->render();
	}  //End displayWaitimgroom
  
  
  	private function getInfoBox($page, $hasTutorPermission, $view=null){
  		global $NUMBERS_OF_PARTICIPANTS, $LENGTH_SELECTION;
  		switch($page){
  			 	case 'main':
  			 		if($view == 'minimize'){
						$icon_standard = 'icons/16/grey/arr_1right.png';
						$icon_minimize = 'icons/16/red/arr_1right.png';
					}
					else{
						$icon_standard = 'icons/16/red/arr_1right.png';
						$icon_minimize = 'icons/16/grey/arr_1right.png';
					}
					$infobox['text'] = array(
							array(
								'kategorie'=>_('Informationen').':',
								'eintrag'=>array(
									array(
										'icon'=>'icons/16/blue/exclaim.png',
										'text'=> sprintf(_('Virtuelle Seminarrume bentigen groe Serverkapazitten. Um einen stabilen Betrieb der Rume zu gewhrleisten ist die Teilnehmerzahl auf max. %d begrenzt.'), max($NUMBERS_OF_PARTICIPANTS))
									),
									array(
										'icon'=>'icons/16/blue/download.png',
										'text'=>_('Falls innerhalb eines virtuellen Raumes Aufzeichnungen angefertigt werden, stehen diese nach Sitzungssende den Tutoren und Dozenten zur Verfgung.')
									),
									array(
										'icon'=>'icons/16/blue/exclaim.png',
										'text'=>_('Um den aktuellen Status des virtuellen Raumes zu erfragen wechseln Sie bitte in die "Erweiterte Ansicht"')
									)
								)
							),
							array(
								'kategorie'  => _('Ansicht:'),
								'eintrag' => array(
									array(
										'icon' => $icon_standard,
										'text' => '<a href="'.URLHelper::getLink('?view=standard').'">'._('Standard').'</a>'
									),
									array(
										'icon' => $icon_minimize,
										'text' => '<a href="'.URLHelper::getLink('?view=minimize').'">'._('Minimiert').'</a>'
									)
								)
							)
					);
					$infobox['picture']='infobox/lectures.jpg';		
  					return $infobox;
  			 	
  				case 'config':
					//echo $this->getPluginURL().'/images/video.png';
					//echo '<img src="'.$this->getPluginURL().'/images/video.png" alt="Logo portaLE">';
  					$infobox['text'] = array(
						array(
							'kategorie' => _('Information:'),
							'eintrag' => array(
								array(
									'icon' => 'icons/16/blue/exclaim.png',
									'text' => sprintf(_('Virtuelle Seminarrume bentigen groe Serverkapazitten. Um einen stabilen Betrieb der Rume zu gewhrleisten wurden die folgenden Grenzwerte durch den Systemadministrator festgelegt: <br/><br/><b>max. Anzahl TeilnehmerInnen:</b> %d <br/><b>Anzahl Rume pro Veranstaltung:</b>  %s <br/><b>max. Sitzungsdauer:</b> %d min <br/><b>Verfgbarkeit der Inhalte nach Sitzungsende:</b> %d Tage <br><br><a href="http://www.uni-trier.de/index.php?id=33410#c77472" target="_blank"><br><img src="'.$this->getPluginURL().'/images/logo_portaLE.png" alt="Link to page: http://www.uni-trier.de/index.php?id=33410#c77472"><br><b>zur portaLE Homepage</b><br></a>'), max($NUMBERS_OF_PARTICIPANTS), (MAX_CONFERENCE_NUMBER > 0)? MAX_CONFERENCE_NUMBER : '&ndash;', max($LENGTH_SELECTION), STORAGE_TIME/86400)
								)
							)
						)
					);
					$infobox['picture']='infobox/dates.jpg';
  					return $infobox;
  			 	
  				case 'waitingroom':
  					if($hasTutorPermission){
  						$hint1 = array(
									'icon'=>'icons/16/blue/exclaim.png',
									'text'=>_('Auf dieser Seite knnen Sie Ihr Wartezimmer verwalten. Sie knnen TeilnehmerInnen zur Sprechstunde in den virtuellen Raum einladen oder aus dem Wartezimmer entfernen. ber die Aktion "Information Wartezimmer" knnen Informationen an alle Wartenden hinterlegt werden. Weiterhin ist es mglich ber "Wartezimmer absperren" den Zugang fr weitere Teilnehmer zu verwehren.')
						);
  					}
  					else{
  						$hint1 = array(
									'icon'=>'icons/16/blue/exclaim.png',
									'text'=>_('Auf dieser Seite sehen Sie die Liste der Personen, die auf Einlass in den virtuellen Raum warten. Sie knnen den Raum erst betreten, nachdem Ihnen der Dozent/die Dozentin Zutritt gewhrt hat. Falls Sie sich aus dem Wartezimmer wieder abmelden wollen, verwenden Sie bitte den Button "Verlassen" hinter Ihrem Namen.')
						);
  					}
  					if($GLOBALS['auth']->auth['jscript']){
  						if($hasTutorPermission){
  							$hint2 = array(
									'icon'=>'icons/16/blue/exclaim.png',
									'text'=>_('Bitte lassen Sie diese Seite whrend der Sprechstunde geffnet. Sie aktualisiert sich automatisch, sobald es nderungen innerhalb des Wartezimmers gibt.')
								);
  						}
  						else{
  							$hint2 = array(
									'icon'=>'icons/16/blue/exclaim.png',
									'text'=>_('Bitte lassen Sie diese Seite geffnet, whrend Sie auf Einlass warten. Die Seite aktualisiert sich automatisch, sobald es nderungen innerhalb des Wartezimmers gibt.')
								);
  						}
  					}
					else{
						$hint2 = array(
									'icon'=>'icons/16/blue/exclaim.png',
									'text'=>_('<b>Achtung:</b> Da Ihr Internet-Browser kein JavaScript untersttzt, kann die Seite nicht automatisch aktualisiert werden. Bitte klicken Sie zur Aktualisierung in der Menzeile auf den Link "Wartezimmer".')
								);
					}
					if($hasTutorPermission){
						$status = Waitingroom::getStatus(Request::int('id'));
						if($status)
							$text3 = '<a href="'.PluginEngine::getLink($this, array('action' => 'waitingroom', 'id' => Request::int('id'), 'closeroom' => 'false')).'">'._('Wartezimmer wieder ffnen').'</a>';
						else
							$text3 = '<a href="'.PluginEngine::getLink($this, array('action' => 'waitingroom', 'id' => Request::int('id'), 'closeroom' => 'true')).'">'._('Wartezimmer schlieen').'</a>';
						$hint3 = array(
								'kategorie'  => _('Aktionen:'),
								'eintrag' => array(
									array(
										'icon' => 'icons/16/blue/admin.png',
										'text' => $text3 
									),
/*									array(
										'icon' => 'x_transparent.gif',
										'text' => '<a href="'.PluginEngine::getLink($this, array('action' => 'waitingroom', 'server' => $_REQUEST['server'], 'room_id' => $_REQUEST['room_id'], 'kick' => 'true')).'">'._('Virtuellen Raum leeren').'</a>'
									), */
									array(
										'icon' => 'icons/16/blue/mail.png',
										'text' => 'Nachricht in Wartezimmer verffentlichen:<form action="'.PluginEngine::getLink($this, array('action' => 'waitingroom', 'id' => REQUEST::int('id'))).'" method="POST"><input type="text" name="message" value="'.$_REQUEST['message'].'" >'.makebutton('ok', 'input', _('Nachricht senden'), 'send_message').'</form>'
									)
								)
							);
					}
					else
						$hint3 = array();
  					$infobox['text'] = array(
  							array(
  								'kategorie' => _('Informationen:'),
								'eintrag' => array($hint1, $hint2)
  							),
  							$hint3
					);
  					
					$infobox['picture']='infobox/groups.jpg';
					return $infobox;
  			 	
  				default: return;
  			 }
  	}
  	
}  //End class
?>
